{ pkgs, ... }:
{
  xsession.windowManager.i3 = {
    enable = true;
    config = {
      terminal = "alacritty";
    };
  };

  programs = {
    # Browser
    qutebrowser.enable = true;

    # Terminal
    alacritty = {
      enable = true;
      settings = {
        bell = {
          animation = "EaseOutExpo";
          color = "#000000";
          command = { program = "${pkgs.sox}/bin/play"; args = [ "-n" "synth" "sine" "C5" "sine" "E4" "remix" "1-2" "fade" "0.1" "0.2" "0.1" ]; };
          duration = 100;
        };
        cursor = { vi_mode_style = "Underline"; };
        hints = {
          enabled = [
            {
              binding = { mods = "Control|Alt"; key = "F"; };
              command = "${pkgs.xdg-utils}/bin/xdg-open";
              mouse = { enabled = true; mods = "Control"; };
              post_processing = true;
              regex = "(mailto:|gemini:|gopher:|https:|http:|news:|file:|git:|ssh:|ftp:)[^\\u0000-\\u001F\\u007F-\\u009F<>\"\\\\s{-}\\\\^⟨⟩`]+";
            }
          ];
        };
        key_bindings = [
          { mode = "~Search"; mods = "Alt|Control"; key = "Space"; action = "ToggleViMode"; }
          { mode = "Vi|~Search"; mods = "Control"; key = "K"; action = "ScrollHalfPageUp"; }
          { mode = "Vi|~Search"; mods = "Control"; key = "J"; action = "ScrollHalfPageDown"; }
          { mode = "~Vi"; mods = "Control|Alt"; key = "V"; action = "Paste"; }
          { mods = "Control|Alt"; key = "C"; action = "Copy"; }
          { mode = "~Search"; mods = "Control|Alt"; key = "F"; action = "SearchForward"; }
          { mode = "~Search"; mods = "Control|Alt"; key = "B"; action = "SearchBackward"; }
          { mode = "Vi|~Search"; mods = "Control|Alt"; key = "C"; action = "ClearSelection"; }
        ];
        window = {
          dynamic_padding = false;
          dynamic_title = true;
        };
      };
    };
  };

  home.packages = with pkgs; [
    # remote
    tigervnc

    # music
    mpd
    mpc-cli
    ashuffle
    vimpc

    # multimedia common
    gimp
    inkscape
    mpv
    mpvScripts.thumbnail
    libreoffice

    # data management
    freefilesync

    # browsers
    firefox

    # fonts
    dejavu_fonts
    twemoji-color-font
    xfce.thunar
    gnome.gedit
    feh
    zathura
    zbar
    zathura
    meld
    python3Packages.magic
    yubikey-touch-detector

    # x11-exclusive
    libgnomekbd # to show keyboard layout
    dunst
    i3lock
    numlockx
    rofi
    rofimoji
    rxvt-unicode
    # TODO urxvt-resize-font-git
    scrot
    simplescreenrecorder
    trayer
    unclutter
    xautolock
    xclip
    lemonbar-xft
    autorandr
    keynav
    sct
    xorg.xinit
    xorg.xbacklight


    # organisation
    rofi-pass # TODO Try autopass.cr
    thunderbird
  ];

}
